@@ -1,5 +1,6 @@
 #include "nadivcc.h"
 
+
 //////////////////////////////////////
 //   M&L 1992 algorithm 
 //   as presented in Mrode 2005
@@ -20,65 +21,15 @@ void ainvml(
 	int *nzmaxA
 ){         
 
-  int     lb, step, it, j, k, h, cnt, sj, dj, istart;
-  double  ai, alphai;
-  double  *AN = new double[2*n[0]];
-  double  *li = new double[n[0]];
+  int     lb, step, it, k, h, sj, dj, istart;
+  double  alphai;
 
-  for(k=g[0]; k<n[0]; k++){
-     li[k]=0.0;               // set l to zero
-  }
-  for(k=g[0]; k<n[0]; k++){
-     AN[k]=-1;               // set AN to zero
-  }
 
-  for(k=g[0]; k<n[0]; k++){  // iterate through each row of l 
-    dii[k] = 0.5-0.25*(f[dam[k]]+f[sire[k]]);
-    if((k > 0) && (dam[k] == dam[k-1]) && (sire[k] == sire[k-1])){
-      f[k] += f[k-1];
-    } 
-    else {
-      li[k] = 1.0;                   // set l_ii to one
-      ai=0.0;                        // set a_ii to zero
-      j=k;
-      cnt=0;
-      while(j>=0){
-        sj=sire[j];
-        dj=dam[j];
-
-        if((sj >= g[0]) && (sj!= n[0])){
-          AN[cnt] = sj;
-          li[sj] += 0.5*li[j];
-          cnt++;
-        }
-
-        if((dj >= g[0]) && (dj!= n[0])){
-          AN[cnt] = dj;
-          li[dj] += 0.5*li[j];
-          cnt++;
-        }
-
-        ai += li[j]*li[j]*dii[j];
-        j=-1;
-
-        for(h=0; h<cnt; h++){   // find eldest individual
-          if(AN[h]>j){
-            j = AN[h];
-          }
-        }
-        for(h=0; h<cnt; h++){   // delete duplicates
-          if(AN[h]==j){
-            AN[h] -= n[0];
-          }
-        }
-      }  // end of while
-      f[k] = ai-1.0;
-      for(h=0; h<=k; h++){
-        li[h]  = 0.0;            // reset l to zero except l_ii =1
-      }
-
-    } // end else for checking if k has same parents as k-1
+  // Meuwissen and Luo 1992 algorithm to obtain f and dii values
+  //TODO FIXME: last argument assumes f NOT supplied by user
+  ml(dam, sire, f, dii, n[0], g[0], 1);
 
+  for(k = g[0]; k < n[0]; ++k){  // iterate through each individual (not groups)
     // check to see if k has 2 phantom parents from same genetic group
     sj = sire[k];
     dj = dam[k];
@@ -92,8 +43,8 @@ void ainvml(
         step = lb/2;
         it = h + step;
         if(iA[it] < k){
-          h=++it;
-          lb-=step+1;
+          h = ++it;
+          lb -= step + 1;
         }
         else lb = step;
       }  // end while
@@ -116,16 +67,16 @@ void ainvml(
               lb = pA[sj+1] - 1 - h;
               while(lb > 0){
                 step = lb/2;
-                it= h + step;
+                it = h + step;
                 if(iA[it] < dj){
-                  h=++it;
-                  lb-=step+1;
+                  h = ++it;
+                  lb -= step+1;
                 }
                 else lb = step;
               }
               if(iA[h] == dj) xA[h] += alphai;
             }
-         }
+         }  // end if sj <= dj
          // sire,k
          h = istart;
          lb = pA[sj+1] - 1 - h;
@@ -133,13 +84,13 @@ void ainvml(
            step = lb/2;
            it = h + step;
            if(iA[it] < k){
-             h=++it;
-             lb-=step+1;
+             h = ++it;
+             lb -= step+1;
            }
            else lb = step;
          }
          if(iA[h] == k) xA[h] += alphai * -2.0;
-      }
+      } // end if sj not missing
       if(dj != n[0]){
          istart = pA[dj];
          // dam,dam
@@ -152,11 +103,11 @@ void ainvml(
            step = lb/2;
            it = h + step;
            if(iA[it] < k){
-             h=++it;
-             lb-=step+1;
+             h = ++it;
+             lb -= step+1;
            }
            else lb = step;
-         }
+         } // end while
          if(iA[h] == k) xA[h] += alphai * -2.0;
          // dam,sire
          if(dj <= sj){
@@ -167,19 +118,18 @@ void ainvml(
                 step = lb/2;
                 it = h + step;
                 if(iA[it] < sj){
-                  h=++it;
-                  lb-=step+1;
+                  h = ++it;
+                  lb -= step+1;
                 }
                 else lb = step;
-              }
+              } // end while
               if(iA[h] == sj) xA[h] += alphai;
-            }
-         }
-       }
-    }
-  } // end of for
-  delete[] AN;
-  delete[] li;
+            } // end if sj not missing
+         } // end if dj <= sj
+       } // end if dj not missing
+    } // end else k doesn't have 2 phantom parents from same group
+  } // end for k
+
 }
 }
 
@@ -187,6 +137,9 @@ void ainvml(
 
 
 
+
+
+
 ///////////////////////////////////////////////////////////////////////////
 //   basically the same M&L 1992 algorithm as 'ainvml', but
 //   with fuzzy classification of genetic groups
@@ -216,56 +169,57 @@ void ainvfuzz(
   double  *AN = new double[2*n[0]];
   double  *li = new double[n[0]];
 
-  for(k=g[0]; k<n[0]; k++){
-     li[k]=0.0;               // set l to zero
+  for(k = g[0]; k < n[0]; k++){
+     li[k] = 0.0;               // set l to zero
   }
-  for(k=g[0]; k<n[0]; k++){
-     AN[k]=-1;               // set AN to zero
+  for(k = g[0]; k < n[0]; k++){
+     AN[k] = -1;        // set AN to "empty" 
+                        //// (since lowest ID is 0, make empty as 1 less than it)
   }
 
-  for(k=g[0]; k<n[0]; k++){  // iterate through each row of l 
-    dii[k] = 0.5-0.25*(f[dam[k]]+f[sire[k]]);
+  for(k = g[0]; k < n[0]; k++){  // iterate through each row of l 
+    dii[k] = 0.5 - 0.25*(f[dam[k]] + f[sire[k]]);
     if((k > 0) && (phdam[k] == phdam[k-1]) && (phsire[k] == phsire[k-1])){
       f[k] += f[k-1];
     } 
     else {
-      li[k] = 1.0;                   // set l_ii to one
-      ai=0.0;                        // set a_ii to zero
-      j=k;
-      cnt=0;
-      while(j>=0){
-        sj=sire[j];
-        dj=dam[j];
+      li[k] = 1.0;                     // set l_ii to one
+      ai = 0.0;                        // set a_ii to zero
+      j = k;
+      cnt = 0;
+      while(j >= 0){
+        sj = sire[j];
+        dj = dam[j];
 
-        if((sj >= g[0]) && (sj!= n[0])){
+        if((sj >= g[0]) && (sj != n[0])){
           AN[cnt] = sj;
           li[sj] += 0.5*li[j];
           cnt++;
         }
 
-        if((dj >= g[0]) && (dj!= n[0])){ 
+        if((dj >= g[0]) && (dj != n[0])){ 
           AN[cnt] = dj;
           li[dj] += 0.5*li[j];
           cnt++;
         }
 
         ai += li[j]*li[j]*dii[j];
-        j=-1;
+        j -= n[0];     // set to value lower than all known identities
 
-        for(h=0; h<cnt; h++){   // find eldest individual
-          if(AN[h]>j){
+        for(h = 0; h < cnt; h++){   // find eldest individual
+          if(AN[h] > j){
             j = AN[h];
           }
         }
-        for(h=0; h<cnt; h++){   // delete duplicates
-          if(AN[h]==j){
-            AN[h] -= n[0]; 
+        for(h = 0; h < cnt; h++){   // delete duplicates
+          if(AN[h] == j){
+            AN[h] -= n[0];      // set to value lower than all known identities 
           }
         }
       }  // end of while
       f[k] = ai-1.0;
-      for(h=0; h<=k; h++){
-        li[h]  = 0.0;            // reset l to zero except l_ii =1
+      for(h = 0; h <= k; h++){
+        li[h] = 0.0;            // reset l to zero
       }
 
     } // end else for checking if k has same parents as k-1
@@ -315,8 +269,8 @@ void ainvfuzz(
               step = lb/2;
               it = h + step;
               if(iA[it] < k){
-                h=++it;
-                lb-=step+1;
+                h = ++it;
+                lb -= step+1;
               }
               else lb = step;
             }
@@ -336,8 +290,8 @@ void ainvfuzz(
                     step = lb/2;
                     it = i + step;
                     if(iA[it] < s){
-                      i=++it;
-                      lb-=step+1;
+                      i = ++it;
+                      lb -= step+1;
                     }
                     else lb = step;
                   }
@@ -363,16 +317,16 @@ void ainvfuzz(
             pik += xF[j];
             // k,dam-group d
             aistart = pA[d];
-            h  =aistart;
+            h = aistart;
             lb = pA[d+1] - 1 - h;
             while(lb > 0){
               step = lb/2;
               it = h + step;
               if(iA[it] < k){
-                h=++it;
-                lb-=step+1;
+                h = ++it;
+                lb -= step+1;
               }
-              else lb  =step;
+              else lb = step;
             }
             if(iA[h] == k) xA[h] += alphai * -2.0 * pik;
 
@@ -384,14 +338,14 @@ void ainvfuzz(
                   pikp += xF[h];
                   // group, k's dam's-group dp
                   aistart = pA[dp];
-                  i  =aistart;
+                  i = aistart;
                   lb = pA[dp+1] - 1 - i;
                   while(lb > 0){
                     step = lb/2;
                     it = i + step;
                     if(iA[it] < d){
-                      i=++it;
-                      lb-=step+1;
+                      i = ++it;
+                      lb -= step+1;
                     }
                     else lb = step;
                   }
@@ -430,8 +384,8 @@ void ainvfuzz(
                       step = lb/2;
                       it = i + step;
                       if(iA[it] < max(s, d)){
-                        i=++it;
-                        lb-=step+1;
+                        i = ++it;
+                        lb -= step+1;
                       }
                       else lb = step;
                     }
@@ -494,8 +448,8 @@ void ainvfuzz(
                     step = lb/2;
                     it = i + step;
                     if(iA[it] < s){
-                      i=++it;
-                      lb-=step+1;
+                      i = ++it;
+                      lb -= step+1;
                     }
                     else lb = step;
                   }
@@ -521,8 +475,8 @@ void ainvfuzz(
         step = lb/2;
         it = j + step;
         if(iA[it] < k){
-          j=++it;
-          lb-=step+1;
+          j = ++it;
+          lb -= step+1;
         }
         else lb = step;
       }
@@ -547,8 +501,8 @@ void ainvfuzz(
         step = lb/2;
         it = j + step;
         if(iA[it] < k){
-          j=++it;
-          lb-=step+1;
+          j = ++it;
+          lb -= step+1;
         }
         else lb = step;
       }
@@ -587,8 +541,8 @@ void ainvfuzz(
                     step = lb/2;
                     it= i + step;
                     if(iA[it] < d){
-                      i=++it;
-                      lb-=step+1;
+                      i = ++it;
+                      lb -= step+1;
                     }
                     else lb = step;
                   }
@@ -652,134 +606,3 @@ void ainvfuzz(
 }
 
 
-
-///////////////////////////////////////////////////////////////////////
-//	Used in makeA()
-////   based on Hadfield's implementation of 
-////   in MCMCglmm (nadiv < v2.13.4)
-
-extern "C"{  
-
-void acinv(
-        int *dam,       
-        int *sire,         
-        double *f,     
-	int *iTinvP,              
-	int *pTinvP,	         
-	double *xTinvP,
-        int *nTinvP,
-	int *nzmaxTinvP,
-	int *iAP,
-	int *pAP,
-	double *xAP,
-	int *nzmaxAP
-){         
-
-  int     j, k, h, ntwo, cnt, sj, dj;
-  double  ai;
-  double  *AN = new double[2*nTinvP[0]];
-  double  *li = new double[nTinvP[0]];
-  cs *Tinv, *D, *tTinv, *tTD;
-
-  for(k=0; k<nTinvP[0]; k++){
-     li[k]=0.0;               // set l to zero
-  }
-  for(k=0; k<nTinvP[0]; k++){
-     AN[k]=-1;               // set AN to zero
-  }
-
-  ntwo = nTinvP[0];
-
-  Tinv = cs_spalloc(nTinvP[0], nTinvP[0], nzmaxTinvP[0], true, false);  
-         for (k = 0 ; k < nzmaxTinvP[0] ; k++){
-           Tinv->i[k] = iTinvP[k];
-           Tinv->x[k] = xTinvP[k];
-         }
-         for (k = 0 ; k <= nTinvP[0]; k++){
-           Tinv->p[k] = pTinvP[k];
-         }
-   
-  tTinv = cs_transpose(Tinv, true);
-
-  D = cs_spalloc(nTinvP[0], nTinvP[0], nzmaxTinvP[0], true, false);
-	 for (k = 0; k < nTinvP[0]; k++){
-	    D->i[k] = k;
-	    D->x[k] = 1.0;
-	    D->p[k] = k;
-	 }
-	 D->p[nTinvP[0]] = nTinvP[0];
-    
-  for(k=0; k<nTinvP[0]; k++){  // iterate through each row of l 
-
-    li[k] = 1.0;                   // set l_ii to one
-    ai=0.0;                        // set a_ii to zero
-
-    D->x[k] = 0.5-0.25*(f[dam[k]]+f[sire[k]]);
-
-    j=k;
-    cnt=0;
-
-    while(j>=0){
-
-      sj=sire[j];
-      dj=dam[j];
-
-      if(sj!= ntwo){
-        AN[cnt] = sj;
-        li[sj] += 0.5*li[j];
-        cnt++;
-      }
-
-      if(dj!= ntwo){ 
-        AN[cnt] = dj;
-        li[dj] += 0.5*li[j];
-        cnt++;
-      }
-
-      ai += li[j]*li[j]*D->x[j];
-
-      j=-1;
-
-      for(h=0; h<cnt; h++){   // find eldest individual
-       if(AN[h]>j){
-         j = AN[h];
-       }
-      }
-      for(h=0; h<cnt; h++){   // delete duplicates
-        if(AN[h]==j){
-          AN[h] -= ntwo; 
-        }
-      }
-    }  // end of while
-    f[k] = ai-1.0;
-    for(h=0; h<nTinvP[0]; h++){
-      li[h]  = 0.0;            // reset l to zero except l_ii =1
-    }
-  } // end of for
-
-
-  for(k=0; k<nTinvP[0]; k++){  // iterate through each row of l 
-      D->x[k] = sqrt(1.0/(D->x[k]));
-  }
-
-  tTD = cs_multiply(tTinv, D);
-  
-  for (k = 0 ; k < tTD->nzmax; k++){
-    iAP[k] = tTD->i[k];
-    xAP[k] = tTD->x[k];
-  }
-  for (k = 0 ; k <= tTD->n; k++){
-    pAP[k] = tTD->p[k];
-  }
-  nzmaxAP[0] = tTD->nzmax;
-
-  cs_spfree(Tinv);
-  cs_spfree(tTinv);
-  cs_spfree(D);
-  cs_spfree(tTD);
-  delete[] AN;
-  delete[] li;
-}
-}
-
-
